ExistingWorkPolicy enum

An enumeration of the conflict resolution policies when registering one-off work with the same unique name.

This policy determines what happens when you register a one-off task with a unique name that already exists.

See: https://developer.android.com/reference/androidx/work/ExistingWorkPolicy

Inheritance
Available extensions

Values

append → const ExistingWorkPolicy

If there is existing pending (uncompleted) work with the same unique name, append the newly-specified work as a child of all the leaves of that work sequence.

keep → const ExistingWorkPolicy

If there is existing pending (uncompleted) work with the same unique name, do nothing. The new work request is ignored and the existing work continues unchanged.

replace → const ExistingWorkPolicy

If there is existing pending (uncompleted) work with the same unique name, cancel and delete it. The new work request replaces the existing one entirely.

update → const ExistingWorkPolicy

If there is existing pending (uncompleted) work with the same unique name, it will be updated with the new specification. Note: This maps to appendOrReplace in the native implementation.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ExistingWorkPolicy>
A constant List of the values in this enum, in order of their declaration.